==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListDescription } from "./WebListDescription";
/**
 * @hidden
 */
var WebListDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebListDescriptionMetadata, _super);
    function WebListDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListDescriptionMetadata.b = function (a) {
        if (WebListDescriptionMetadata.a == null) {
            WebListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListDescriptionMetadata.c(WebListDescriptionMetadata.a);
        }
        if (a.g(WebListDescriptionMetadata.a)) {
            return;
        }
        a.s(WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:List");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebListDescriptionMetadata.d = function (a) {
        WebListDescriptionMetadata.b(a);
        a.u("WebList", function () { return new WebListDescription(); });
        a.t("WebList", WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.$t = markType(WebListDescriptionMetadata, 'WebListDescriptionMetadata');
    WebListDescriptionMetadata.a = null;
    return WebListDescriptionMetadata;
}(Base));
export { WebListDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebListDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListDescription } from "./WebListDescription";
/**
 * @hidden
 */
var WebListDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebListDescriptionMetadata, _super);
    function WebListDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListDescriptionMetadata.b = function (a) {
        if (WebListDescriptionMetadata.a == null) {
            WebListDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListDescriptionMetadata.c(WebListDescriptionMetadata.a);
        }
        if (a.j(WebListDescriptionMetadata.a)) {
            return;
        }
        a.y(WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:List");
        a.item("__tagNameWC", "String:igc-list");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
    };
    WebListDescriptionMetadata.d = function (a) {
        WebListDescriptionMetadata.b(a);
        a.aa("WebList", function () { return new WebListDescription(); });
        a.z("WebList", WebListDescriptionMetadata.a);
    };
    WebListDescriptionMetadata.$t = markType(WebListDescriptionMetadata, 'WebListDescriptionMetadata');
    WebListDescriptionMetadata.a = null;
    return WebListDescriptionMetadata;
}(Base));
export { WebListDescriptionMetadata };
